#!/usr/bin/python3

# --- BEGIN COPYRIGHT BLOCK ---
# Copyright (C) 2016, William Brown <william at blackhats.net.au>
# All rights reserved.
#
# License: GPL (version 3 or any later version).
# See LICENSE for details.
# --- END COPYRIGHT BLOCK ---

import argparse
from idm389.core import _init_config, _init_plugins, _init_containers, _init_permissions, _init_roles

def init_check(inst, basedn, log, args):
    log.info('Begin initialisation check ...')

    if not _init_config(inst, basedn, log, commit=commit):
        log.error("Config migration check failed")
        return False

    if not _init_plugins(inst, basedn, log, commit=commit):
        log.error("Plugin migration check failed")
        return False

    if not _init_containers(inst, basedn, log, commit=commit):
        log.error("Container migration check failed")
        return False

    if not _init_permissions(inst, basedn, log, commit=commit):
        log.error("Permissions migration check failed")
        return False

    if not _init_roles(inst, basedn, log, commit=commit):
        log.error("Roles migration check failed")
        return False

    log.info('Completed check')

def init(inst, basedn, log, args):
    log.info('Begin initialisation ...')

    if not _init_config(inst, basedn, log, commit=commit):
        log.error("Config migration failed")
        return False

    if not _init_plugins(inst, basedn, log, commit=commit):
        log.error("Plugin migration failed")
        return False

    if not _init_containers(inst, basedn, log, commit=commit):
        log.error("Container migration failed")
        return False

    if not _init_permissions(inst, basedn, log, commit=commit):
        log.error("Permissions migration failed")
        return False

    if not _init_roles(inst, basedn, log, commit=commit):
        log.error("Roles migration failed")
        return False

    log.info('Completed')

def create_parser(subparsers):
    core_parser = subparsers.add_parser('core', help="Manage core functions of dsidm")

    subcommands = core_parser.add_subparsers(help="action")

    init_parser = subcommands.add_parser('init', help="Initilalise a DS server to be idm389 capable")
    init_parser.set_defaults(func=init)

    init_check_parser = subcommands.add_parser('init_check', help="Check if a DS server is idm389 capable")
    init_check_parser.set_defaults(func=init_check)

