#!/usr/bin/python3

# --- BEGIN COPYRIGHT BLOCK ---
# Copyright (C) 2016, William Brown <william at blackhats.net.au>
# All rights reserved.
#
# License: GPL (version 3 or any later version).
# See LICENSE for details.
# --- END COPYRIGHT BLOCK ---


import argparse
from idm389.ipa import IpaUser, IpaUsers, _ipa_migrate

from idm389.cli import _get_args, _warn, connect_instance, disconnect_instance

def _migrate(inst, ipa_inst, basedn, ipa_basedn, log):
    log.debug("Begin migration")
    _ipa_migrate(ipa_inst, inst, ipa_basedn, basedn, log, commit=True)
    log.debug("Migration complete")


def _migrate_check(inst, ipa_inst, basedn, ipa_basedn, log):
    log.debug("Begin migration check")
    # Is there a better way to get the starttls param?
    result = _ipa_migrate(ipa_inst, inst, ipa_basedn, basedn, log, commit=False)
    # disconnect
    log.debug("Migration check status -> %s" % result)
    return result


def migrate(inst, basedn, log, args):
    ipa_inst = None
    kwargs = _get_args( args.extra, [
            ('ipa_basedn', 'Enter basedn of IPA domain', False),
            ('ldapuri', 'Enter ldapuri of IPA master', False),
            # Try and always have password last
            #('password', 'Enter password for cn=Directory Manager', True),
        ])
    try:
        ipa_inst = connect_instance(kwargs['ldapuri'], 'cn=Directory Manager', inst.verbose, starttls=False)
        result = _migrate_check(inst, ipa_inst, basedn, kwargs['ipa_basedn'] , log)
        if result is True:
            _warn(None, msg="This will now migrate from %s to %s" % (kwargs['ipa_basedn'], basedn))
            _migrate(inst, ipa_inst, basedn, kwargs['ipa_basedn'] , log)
    finally:
        disconnect_instance(ipa_inst)

def migrate_check(inst, basedn, log, args):
    ipa_inst = None
    kwargs = _get_args( args.extra, [
            ('ipa_basedn', 'Enter basedn of IPA domain', False),
            ('ldapuri', 'Enter ldapuri of IPA master', False),
            # Try and always have password last
            #('password', 'Enter password for cn=Directory Manager', True),
        ])
    try:
        ipa_inst = connect_instance(kwargs['ldapuri'], 'cn=Directory Manager', inst.verbose, starttls=False)
        _migrate_check(inst, ipa_inst, basedn, kwargs['ipa_basedn'], log)
    finally:
        disconnect_instance(ipa_inst)

def create_parser(subparsers):
    ipa_parser = subparsers.add_parser('ipa', help='IPA Migration tools')

    subcommands = ipa_parser.add_subparsers(help='action')

    migrate_check_parser = subcommands.add_parser('migrate_check', help='Test if a migration is possible')
    migrate_check_parser.set_defaults(func=migrate_check)
    migrate_check_parser.add_argument('extra', nargs=argparse.REMAINDER,
            help='A migrate may take one or more extra arguments. This parameter provides them'
        )

    migrate_parser = subcommands.add_parser('migrate', help='Migrate an IPA instance to DS')
    migrate_parser.set_defaults(func=migrate)
    migrate_parser.add_argument('extra', nargs=argparse.REMAINDER,
            help='A migrate may take one or more extra arguments. This parameter provides them'
        )

# vim: tabstop=4 expandtab shiftwidth=4 softtabstop=4
